/* AboutTab - March 26th, 2001
**
**      Copyright (c) 1997-2001 by Gregory Braun. All rights reserved.
**
**      This routine displays information about the AppPaths Control Panel
**      applet. Private (static) routines are included to initialize the
**      property page sheet when first invoked.
**
**      Called:     dlg = handle to the dialog window.
**                  msg = the MS Windows WM_xxxxxx message to be handled.
**                  wp  = the WPARAM specific to the message being sent
**                  lp  = the LPARAM specific to the message being sent
**
**      Returns:    TRUE upon success, or FALSE if the user pressed [Cancel],
**                  or an internal error exists.
**
**      Notes:      The VERSION resource is read and the information found
**                  there is used as the text for this property sheet.
**
**                  If the initialization routine fails to find the VERSION
**                  resource the default fields as specified in the dialog
**                  box template are used in their place.
**
**                  Information about the AppPaths module is recorded in
**                  four (4) places:
**
**                      The VERSION resource
**                      The dialog box template
**                      The APP_xxxx string resource IDs
**                      The AboutTab function itself.
**
**                  Changes must be made to all four of these locations
**                  to insure the proper display of version information
**                  on all MS Windows 95/98/NT systems.
**
*/

#include "AppPaths.h"

static VERSION  version = {
                            "ProductName",      BLANK_STR,APP_NAME,        "Application Paths 2000",
                            "LegalCopyright",   BLANK_STR,APP_COPYRIGHT,   " 1997-2001 Gregory Braun. All rights reserved.",
                            "FileDescription",  BLANK_STR,APP_DESCRIPTION, "MS Windows Application Paths Control Panel Applet",
                            "FileVersion",      BLANK_STR,APP_VERSION,     "Version 2.5",
                            "Release",          BLANK_STR,APP_RELEASE,     "This software is distributed as freeware. You may copy and distribute this program as long as all copyright notices remain intact and the application files are not modified in any way.",
                            "Comments",         BLANK_STR,APP_COMMENTS,    "Visit the Software Design Web Site on the Internet to download the latest versions of all my software programs. Free source code for this Control Panel Applet is also available there.",
                            "WebSite",          BLANK_STR,APP_WEBSITE,     "http://www.gregorybraun.com",
                          };


static BOOL             initiate    (HWND dlg);
static BOOL             verify      (HWND dlg);
static BOOL             website     (HWND dlg,int item);

extern UINT CALLBACK AboutTab (HWND dlg,UINT msg,WPARAM wp,LPARAM lp)
{
    auto int                item = LOWORD (wp);

    auto BOOL               good;

    switch (msg) {

        case WM_COMMAND :

             switch (item) {

                 case ABOUT_WEBSITE_BTN :
                      website (dlg,item);
                      break;
                      }

             break;

        case WM_HELP :
             HelpTip (dlg,((LPHELPINFO) lp)->iCtrlId);
             break;

        case WM_NOTIFY :

             switch (((LPNMHDR) lp)->code) {

                case PSN_SETACTIVE :
                     initiate (dlg);
                     break;

                case PSN_KILLACTIVE :
                     good = verify (dlg);
                     SetWindowLong (dlg,DWL_MSGRESULT,!good);
                     return ((good) ? FALSE : TRUE);
                     break;

                case PSN_APPLY :
                     good = verify (dlg);
                     SetWindowLong (dlg,DWL_MSGRESULT,good);
                     return ((good) ? PSNRET_NOERROR : PSNRET_INVALID_NOCHANGEPAGE);
                     break;

                case PSN_HELP :
                     HelpTopic (dlg,ABOUT_TAB);
                     break;


               default :
                     break;
                     }

             break;

        break;
        }

     return (FALSE);
}

static BOOL initiate (HWND dlg)
{
    auto LPSTR      info    = NULL;
    auto UINT       lid     = GetUserDefaultLangID ();

    auto int        inx;

    auto DWORD      size;
    auto DWORD      status;

    auto UINT       count;

    auto UINT       language;
    auto UINT       *translation;

    auto LPSTR      ptr;

    auto char       string[PSTRING];
    auto char       windows[PSTRING];
    auto char       unicode[PSTRING];

    if ((size = GetFileVersionInfoSize (program,&status)) == NIL)
        goto fail;

    if ((info = GlobalAllocPtr (GHND,size)) == NULL)
        goto fail;

    if (!GetFileVersionInfo (program,NIL,size,info))
        goto fail;

    if (!VerQueryValue (info,VARFILEINFO_STR,(void **)&translation,&count))
        goto fail;

    language = MAKELONG (HIWORD (*translation),LOWORD (*translation));

    for (inx = NIL; inx < VERSION_ITEM_MAX; inx++) {

        wsprintf (windows,WIN_RES_FMT,lid,version.item[inx].label);
        wsprintf (unicode,UNI_RES_FMT,lid,version.item[inx].label);
        wsprintf (string, LNG_RES_FMT,language,version.item[inx].label);

        if (VerQueryValue (info,windows,&ptr,&count))
            lstrcpy (version.item[inx].value,ptr);

        else if (VerQueryValue (info,unicode,&ptr,&count))
            lstrcpy (version.item[inx].value,ptr);

        else if (VerQueryValue (info,string,&ptr,&count))
            lstrcpy (version.item[inx].value,ptr);

        else if (!LoadString (applet,version.item[inx].id,version.item[inx].value,PSTRING))
            lstrcpy (version.item[inx].value,version.item[inx].sub);

        SetDlgItemText (dlg,ABOUT_NAME_TXT + inx,version.item[inx].value);
        }

fail:

    if (info) GlobalFreePtr (info);

    return (TRUE);
}

static BOOL verify (HWND dlg)
{
    UNUSED_ARG (dlg);

    return (TRUE);
}

static BOOL website (HWND dlg,int item)
{
    auto char   text[PSTRING];

    GetDlgItemText (dlg,item,text,PSTRING);

    return (WebSite (dlg,text));
}

/* end of AboutTab.c - written by Gregory Braun */
